/*================================================
 Program: Master_OC.do
 Author:  Mitchell Hoffman 
 Edited:  March 2019
 Purpose: Master Directory File for Overconfidence Paper
=================================================*/

/*================================================
SET PATHS HERE
Various paths are also declared in:
	~ "zz_globals_panel.do"
================================================*/

global ZPath = ""
global mainpath = ""
global temppath = ""

* New paths for looking only at overconfidence
global fullpath = "../RF"
global logpath = "$fullpath/Log"
global StrucPath = "../Structural"
global ExptPath = "../Expt"


/*================================================
Get the current date-time in string format. 
================================================*/
global date = ""
do "$fullpath/GlobalsTime.do"

/*================================================
Add date-time to end of files.
================================================*/
global spec = "$time"

/*================================================
Start a log.
================================================*/
global logname = "$date.log"
cd "$logpath"
capture log close
log using "$logname", append


/*================================================
Reduced-form analysis with New Hire Panel
=================================================*/
do "$fullpath/zz_globals_panel.do"

* Cleans main data from Firm A. 
* HAS CONFIDENTIAL INFO IN IT. NOT INCLUDED.
qui do "$fullpath/Clean_NHP.do"

* Extract the CPS data
qui do "$fullpath/CPS_Extract.do"

* Clean the CPS data
qui do "$fullpath/CPS_Clean.do"

* Do the analysis
qui do "$fullpath/OC_Panel.do"

/*================================================
Read data into Matlab for Structural Analysis:
=================================================*/
set more off

* Re-shape the data into wide format.
qui do "$fullpath/Reshape_OC.do"

* Create an .asc file to input into Matlab.
qui do "$fullpath/Panel_Input_OC.do"


/*================================================
Perform Structural Analysis
=================================================*/
* matlab Master.m


/*================================================
Field experiment on driver beliefs at Firm B
=================================================*/

* Clean the data. 
* HAS CONFIDENTIAL INFO IN IT. NOT INCLUDED.
do "$ExptPath/Clean_Expt.do"

* Do the analysis
do "$ExptPath/OC_Expt.do"




