/*================================================
 Program: Panel_Input_OC.do
 Edited:  January 2019
 Purpose: Inputs data to Matlab
=================================================*/

clear
set more off
use "$Tmp/Panel_Reshaped.dta", clear

* "Quitflag" and "Fireflag" are one when quit or fire occurs, otherwise 0.
* We want to eventually convert them to having 0's or -9's.
foreach zX in quit fire{
forvalues iX=1/110{
	assert `zX'flag`iX'==1 | mi(`zX'flag`iX')	
	label variable `zX'flag`iX' "`zX' decision during week `iX'"
}
}

* Quit or fired decision during the first week.
foreach yX in quitflag fireflag{
	replace `yX'1=0 if `yX'1~=1
}
forvalues iX=2/110{
	local kX = `iX'-1
* Look for where someone has a quit or fire flag. After that point, they are censored.	
	replace quitflag`iX'=-9 if quitflag`kX'==-9 | quitflag`kX'==1 | fireflag`kX'==1
	replace fireflag`iX'=-9 if fireflag`kX'==-9 | fireflag`kX'==1 | quitflag`kX'==1
* Before that point, if they have not left yet, I say that they have not quit and not been fired.	
	foreach yX in quitflag fireflag{
		replace `yX'`iX'=0 if mi(`yX'`iX') & ~mi(MergeDate`iX')
	}
* Convert missing quitflag or fireflag records to -9.
	foreach yX in quitflag fireflag{
		replace `yX'`iX'=-9 if mi(`yX'`iX')
	}
}

* We define "staying" as the opposite of quitting.
forvalues iX=1/110{
	gen stayflag`iX'=quitflag`iX'
	recode stayflag`iX' (1=0) (0=1) (-9=-9)
}

* Set miles to -9 if stay is missing or miles are missing. 
forvalues iX=1/110{
	replace miles`iX'=-9 if stayflag`iX'==-9 | mi(miles`iX')
	label variable miles`iX' "Miles during week `iX'"
}	

/*
"mmiles(t)" is average miles to date through week t.
We start in week 6, the first week after the 5 weeks of 
on-the-job training. We calculate the average focusing only
on the weeks with positive miles.
*/
gen tmiles6 = miles6*(miles6>0)
gen count6 = 1*(miles6>0)
gen mmiles6 = miles6 if miles6>0
forvalues iX=7/110{
	local kX = `iX'-1
	gen tmiles`iX' = tmiles`kX'+miles`iX'*(miles`iX'>0)
	gen count`iX' = count`kX'+(miles`iX'>0)
	gen mmiles`iX' = tmiles`iX'/count`iX' if count`iX'!=count`kX' 
	replace  mmiles`iX'=mmiles`kX' if count`iX'==count`kX'
}

* Avg miles to date can only be non-missing if stay decision is non-missing.
forvalues iX=6/110{
	replace mmiles`iX'=-9 if stayflag`iX'==-9
	replace mmiles`iX'=-9 if mi(mmiles`iX')
	label variable mmiles`iX' "Average miles to date `iX'"
}


* Average miles to date is set to missing (or -9 for our Matlab purposes)
* during the 5 weeks of on-the-job training.
forvalues iX=1/5{
	gen mmiles`iX'=-9
}

* Convert missing values of beliefs to -9.
forvalues iX=1/110{
	replace pmiles`iX' = -9 if mi(pmiles`iX')
}


	
* 4 main parts to data: Stay decisions, miles, avg miles to date, beliefs.	
order Subject ///
stayflag1 stayflag2 stayflag3 stayflag4 stayflag5 stayflag6 stayflag7 stayflag8 stayflag9 stayflag10 ///
stayflag11 stayflag12 stayflag13 stayflag14 stayflag15 stayflag16 stayflag17 stayflag18 stayflag19 stayflag20 ///
stayflag21 stayflag22 stayflag23 stayflag24 stayflag25 stayflag26 stayflag27 stayflag28 stayflag29 stayflag30 ///
stayflag31 stayflag32 stayflag33 stayflag34 stayflag35 stayflag36 stayflag37 stayflag38 stayflag39 stayflag40 ///
stayflag41 stayflag42 stayflag43 stayflag44 stayflag45 stayflag46 stayflag47 stayflag48 stayflag49 stayflag50 ///
stayflag51 stayflag52 stayflag53 stayflag54 stayflag55 stayflag56 stayflag57 stayflag58 stayflag59 stayflag60 ///
stayflag61 stayflag62 stayflag63 stayflag64 stayflag65 stayflag66 stayflag67 stayflag68 stayflag69 stayflag70 ///
stayflag71 stayflag72 stayflag73 stayflag74 stayflag75 stayflag76 stayflag77 stayflag78 stayflag79 stayflag80 ///
stayflag81 stayflag82 stayflag83 stayflag84 stayflag85 stayflag86 stayflag87 stayflag88 stayflag89 stayflag90 ///
stayflag91 stayflag92 stayflag93 stayflag94 stayflag95 stayflag96 stayflag97 stayflag98 stayflag99 stayflag100 ///
stayflag101 stayflag102 stayflag103 stayflag104 stayflag105 stayflag106 stayflag107 stayflag108 stayflag109 stayflag110 ///
miles1 miles2 miles3 miles4 miles5 miles6 miles7 miles8 miles9 miles10 ///
miles11 miles12 miles13 miles14 miles15 miles16 miles17 miles18 miles19 miles20 ///
miles21 miles22 miles23 miles24 miles25 miles26 miles27 miles28 miles29 miles30 ///
miles31 miles32 miles33 miles34 miles35 miles36 miles37 miles38 miles39 miles40 ///
miles41 miles42 miles43 miles44 miles45 miles46 miles47 miles48 miles49 miles50 ///
miles51 miles52 miles53 miles54 miles55 miles56 miles57 miles58 miles59 miles60 ///
miles61 miles62 miles63 miles64 miles65 miles66 miles67 miles68 miles69 miles70 ///
miles71 miles72 miles73 miles74 miles75 miles76 miles77 miles78 miles79 miles80 ///
miles81 miles82 miles83 miles84 miles85 miles86 miles87 miles88 miles89 miles90 ///
miles91 miles92 miles93 miles94 miles95 miles96 miles97 miles98 miles99 miles100 ///
miles101 miles102 miles103 miles104 miles105 miles106 miles107 miles108 miles109 miles110 ///
mmiles1 mmiles2 mmiles3 mmiles4 mmiles5 mmiles6 mmiles7 mmiles8 mmiles9 mmiles10 ///
mmiles11 mmiles12 mmiles13 mmiles14 mmiles15 mmiles16 mmiles17 mmiles18 mmiles19 mmiles20 ///
mmiles21 mmiles22 mmiles23 mmiles24 mmiles25 mmiles26 mmiles27 mmiles28 mmiles29 mmiles30 ///
mmiles31 mmiles32 mmiles33 mmiles34 mmiles35 mmiles36 mmiles37 mmiles38 mmiles39 mmiles40 ///
mmiles41 mmiles42 mmiles43 mmiles44 mmiles45 mmiles46 mmiles47 mmiles48 mmiles49 mmiles50 ///
mmiles51 mmiles52 mmiles53 mmiles54 mmiles55 mmiles56 mmiles57 mmiles58 mmiles59 mmiles60 ///
mmiles61 mmiles62 mmiles63 mmiles64 mmiles65 mmiles66 mmiles67 mmiles68 mmiles69 mmiles70 ///
mmiles71 mmiles72 mmiles73 mmiles74 mmiles75 mmiles76 mmiles77 mmiles78 mmiles79 mmiles80 ///
mmiles81 mmiles82 mmiles83 mmiles84 mmiles85 mmiles86 mmiles87 mmiles88 mmiles89 mmiles90 ///
mmiles91 mmiles92 mmiles93 mmiles94 mmiles95 mmiles96 mmiles97 mmiles98 mmiles99 mmiles100 ///
mmiles101 mmiles102 mmiles103 mmiles104 mmiles105 mmiles106 mmiles107 mmiles108 mmiles109 mmiles110 ///
pmiles1 pmiles2 pmiles3 pmiles4 pmiles5 pmiles6 pmiles7 pmiles8 pmiles9 pmiles10 ///
pmiles11 pmiles12 pmiles13 pmiles14 pmiles15 pmiles16 pmiles17 pmiles18 pmiles19 pmiles20 ///
pmiles21 pmiles22 pmiles23 pmiles24 pmiles25 pmiles26 pmiles27 pmiles28 pmiles29 pmiles30 ///
pmiles31 pmiles32 pmiles33 pmiles34 pmiles35 pmiles36 pmiles37 pmiles38 pmiles39 pmiles40 ///
pmiles41 pmiles42 pmiles43 pmiles44 pmiles45 pmiles46 pmiles47 pmiles48 pmiles49 pmiles50 ///
pmiles51 pmiles52 pmiles53 pmiles54 pmiles55 pmiles56 pmiles57 pmiles58 pmiles59 pmiles60 ///
pmiles61 pmiles62 pmiles63 pmiles64 pmiles65 pmiles66 pmiles67 pmiles68 pmiles69 pmiles70 ///
pmiles71 pmiles72 pmiles73 pmiles74 pmiles75 pmiles76 pmiles77 pmiles78 pmiles79 pmiles80 ///
pmiles81 pmiles82 pmiles83 pmiles84 pmiles85 pmiles86 pmiles87 pmiles88 pmiles89 pmiles90 ///
pmiles91 pmiles92 pmiles93 pmiles94 pmiles95 pmiles96 pmiles97 pmiles98 pmiles99 pmiles100 ///
pmiles101 pmiles102 pmiles103 pmiles104 pmiles105 pmiles106 pmiles107 pmiles108 pmiles109 pmiles110 ///


* New ID to start at one for numbering in structural model.
gen newid = _n
order newid


cf _all using "$Tmp/LastFile.dta"
save "$Tmp/LastFile.dta", replace
use "$Tmp/LastFile.dta", clear

outfile newid stayflag1-stayflag110 miles1-miles110 mmiles1-mmiles110 pmiles1-pmiles110 RaceAfAm RaceHisp ///
	GenFemaleVsAll numeracyhalf patiencehalf iqhalf education age using "$StrucPath/Panel_Truck.asc", nolabel replace wide

