%{
====================================================
File name: Master.m
Modified: March 2019
Project: Overconfidence in trucking
Description: Executes code for structural model.
====================================================
%}

clc
clear all

% Specifies standard options.
zz_std_options;

% Go to long format
format long;

%{
SET THE SPECIFICATION
%}
time_now = strcat('OC_',datestr(now,'yyyy_mm_dd_HH_MM_SS'));


%% Table 4, Column 1.

% T4C1 using "fminunc".
zz_std_options;
op.beliefbias = 'no_bias';
op.first5 = 'first5';
op.timetrend = 'no';
op.ootimetrend = 'no';
EstimatesName = 'mp3_NB_bt10k';
run_full;

% T4C1: Verify that same results with "fminsearch".
zz_std_options;
op.beliefbias = 'no_bias';
op.first5 = 'first5';
op.timetrend = 'no';
op.ootimetrend = 'no';
EstimatesName = 'mp3_NB_bt10k_FMS';
op.solver = 'fminsearch';
run_full;


%% Table 4, Column 2.
% T4C2 using "fminunc".
zz_std_options;
op.beliefbias = 'prior';
op.first5 = 'first5';
op.timetrend = 'no';
op.ootimetrend = 'no';
EstimatesName = 'mp3_mp1_bt10k';
run_full;
% Table 6. Profit calculation based on estimates.
counterfactual = 'elim_overconf';
overconf_factor = 1;
run predict_sims_OC.m
overconf_factor = .5;
run predict_sims_OC.m
% Appendix stat on 50% debiasing at 9 weeks.
round(simpr_surviv(9)-simpr_surviv_contrfac(9),2)
overconf_factor = zero_overconf;
run predict_sims_OC.m

% T4C2: Verify that same results with "fminsearch".
zz_std_options;
op.beliefbias = 'prior';
op.first5 = 'first5';
op.timetrend = 'no';
op.ootimetrend = 'no';
EstimatesName = 'mp3_mp1_bt10k_FMS';
op.solver = 'fminsearch';
run_full;



%% Table 5, Column 1.
% "fminunc" followed by "fminsearch". 
zz_std_options;
op.beliefbias = 'no_bias';
op.first5 = 'no';
op.timetrend = 'logit';
op.ootimetrend = 'logit';
op.solver = 'fminunc&fminsearch';
EstimatesName = 'mp3_NB_bt10k_LBD_OOL_FMU&FMS';
run_full;


%% Table 5, Column 2. 
% "fminunc" followed by "fminsearch". 
zz_std_options;
op.beliefbias = 'prior';
op.first5 = 'no';
op.timetrend = 'logit';
op.ootimetrend = 'logit';
op.solver = 'fminunc&fminsearch';
EstimatesName = 'mp3_mp1_bt10k_LBD_OOL_FMU&FMS';
run_full;



%% Appendix F Results

% Figure F2: Standard Learning, i.e., No Variance Bias
zz_std_options;
op.learnspeed = 'standard';
op.beliefbias = 'prior';
op.first5 = 'no';
op.timetrend = 'logit';
op.ootimetrend = 'logit';
op.solver = 'fminunc&fminsearch';
EstimatesName = 'mp3_mp1StdLearn_bt10k_LBD_OOL_FMU&FMS';
run_full;

% Table F1, Column 2, Annual discount factor of 0.9.
% Because mu1 is close to -375 restriction, we use fminconc 
% followed by fminunc.
zz_std_options;
op.delta=(.90)^(1/52); 
op.beliefbias = 'prior';
op.first5 = 'first5';
op.timetrend = 'no';
op.ootimetrend = 'no';
op.solver = 'fmincon&fminunc';
EstimatesName = 'mp3_mp1_bt10k_Del90';
run_full;

% Table F1, Column 3, Inverse probability weighting
zz_std_options;
op.ipw = 'yes'; 
op.beliefbias = 'prior';
op.first5 = 'first5';
op.timetrend = 'no';
op.ootimetrend = 'no';
op.solver = 'fmincon&fminunc';
EstimatesName = 'mp3_mp1_bt10k_IPW';
run_full;

% Table F1, Column 4, Winsorize beliefs at 4k
zz_std_options;
op.WINSTHRES = 4000;
op.beliefbias = 'prior';
op.first5 = 'first5';
op.timetrend = 'no';
op.ootimetrend = 'no';
EstimatesName = 'mp3_mp1_bt10k_bWinsz4k';
run_full;

% Table F1, Column 5, Allow learning for up to 200 periods
zz_std_options;
NPER = 200;
op.beliefbias = 'prior';
op.first5 = 'first5';
op.timetrend = 'no';
op.ootimetrend = 'no';
op.solver = 'fmincon&fminunc';
EstimatesName = 'mp3_mp1_bt10k_T200';
run_full;

% Table F1, Column 6, Higher outside option
zz_std_options;
rwage = 8;
op.beliefbias = 'prior';
op.first5 = 'first5';
op.timetrend = 'no';
op.ootimetrend = 'no';
EstimatesName = 'mp3_mp1_bt10k_r8';
run_full;

% Table F1, Column 7, Finer grid
zz_std_options;
op.grid_ys = (1:1:40)';
op.beliefbias = 'prior';
op.first5 = 'first5';
op.timetrend = 'no';
op.ootimetrend = 'no';
EstimatesName = 'mp3_mp1_bt10k_Grid-1140';
run_full;


%% Additional results

% Appendix A10: Additional Structural Robustness Checks
% Trim beliefs at 4k.
zz_std_options;
op.BELIEFTHRES = 4000;
op.beliefbias = 'prior';
op.first5 = 'first5';
op.timetrend = 'no';
op.ootimetrend = 'no';
EstimatesName = 'mp3_mp1_bt10k_bt4k';
run_full;

% Annual discount factor of 0.
zz_std_options;
op.delta=0^(1/52); 
op.beliefbias = 'prior';
op.first5 = 'first5';
op.timetrend = 'no';
op.ootimetrend = 'no';
op.tasteuhprobrestrict = 'yes';
EstimatesName = 'mp3_mp1_bt10k_DelZero';
op.solver = 'fmincon&fminunc';
run_full;

% Measurement error correction
zz_std_options;
op.dataname = 'Panel_Truck_ME.asc';
op.beliefbias = 'prior';
op.first5 = 'first5';
op.timetrend = 'no';
op.ootimetrend = 'no';
EstimatesName = 'mp3_mp1_bt10k_ME';
op.solver = 'fmincon&fminunc';
run_full;



