%{
====================================================
Script name: doit_bhhh.m
Modified: January 2018 by Mitchell Hoffman
Project: Overconfidence in trucking
Description: Calculates SEs by BHHH.
====================================================
%}

function [ses_bhhh,grad_MH] = doit_bhhh(paramhat,tol)

global NOBS NAMES op

nparams = length(paramhat);

% If tolerance does not exist, default to below.
if ~exist('tol','var')
      tol = op.tol_ND;
end

% Make matrix with tolerance on diagonal.
vv = zeros(nparams,nparams);
for iX=1:nparams
    vv(iX,iX)=tol;
end

% sc is derivative of likelihood wrt parameters.
sc = ones(NOBS,nparams); 
for iX=1:nparams
    sc(:,iX)=(vec_loglik(paramhat+vv(:,iX))-vec_loglik(paramhat)) ./ tol;
end

grad_MH = -sum(sc',2);

% Variance is inverse of outer product of gradient.
% We use pseudo-inverse here.
var_bhhh = pinv(sc'*sc);
ses_bhhh = sqrt(diag(var_bhhh));

% Display results.
disp(' ');
disp(' ');
disp(['Tolerance is: ' num2str(tol)]);
disp('ESTIMATION RESULTS, WITH BHHH STANDARD ERRORS');
disp('              ---------------------------- ');
disp('                Est         SE      t-stat');
for rX=1:length(NAMES)
    fprintf('%-10s %10.4f %10.4f %10.4f\n', NAMES{rX,1}, [100*paramhat(rX,1) 100*ses_bhhh(rX,1) paramhat(rX,1)./ses_bhhh(rX,1) ]);
end





end
