%{
====================================================
Script name: set_params.m
Modified: February 2019
Project: Overconfidence in trucking.
Description: Assigns coefficient values to parameters 
in likelihood function. Specifically, it takes the
vector "coef", and depending on the options chosen, it
assigns values to the relevant variables.
====================================================
%}

%% Baseline parameters.
if strcmp(runmode,'test_mode')~=1 && strcmp(baseline,'baseline')==1 
    tau = coef(1);
    eta0 = coef(2);
    sig_0 = coef(3);
    sig_y = coef(4);
end

if strcmp(runmode,'test_mode')~=1 && ( strcmp(baseline,'earn_params_only')==1 ...
        || strcmp(baseline,'earn&belief_params_only')==1)
    tau=1;
    eta0 = coef(1);
    sig_0 = coef(2);
    sig_y = coef(3);
end

epmean = 0;
% Euler's constant.
euler = -psi(1);

if strcmp(baseline,'LBD_only')==1 
    sig_y=0;
end



%% Set zeros.
a1=0;
a2=0;
mu1 = 0;
mu2 = 0;
mu3=0;
puh12 = 0;
eta_b=0;
sig_b=0;
sig_y_tilda = sig_y;
theta1= 0;
v_ojt=0;
puh13=0;
puh23=0;


%% Option to Fix everything else and estimate learning by doing.
if strcmp(baseline,'LBD_only')==1 
zzz=load('Estimates/Estimates_for_LBDOnly.mat','paramhat','NAMES');    
NAMES_ALL = zzz.NAMES;  
ZESTIMATES = zzz.paramhat;
    for i=1:length(NAMES_ALL)
        if strcmp(NAMES_ALL(i),'tau')==1
            tau = ZESTIMATES(i);
        end
        if strcmp(NAMES_ALL(i),'eta0')==1
            eta0 = ZESTIMATES(i);
        end
        if strcmp(NAMES_ALL(i),'sig_0')==1
            sig_0 = ZESTIMATES(i);
        end
        if strcmp(NAMES_ALL(i),'sig_y')==1
            sig_y = ZESTIMATES(i);
        end
        if strcmp(NAMES_ALL(i),'theta1')==1
            theta1 = ZESTIMATES(i);
        end
        if strcmp(NAMES_ALL(i),'theta2')==1
            theta2 = ZESTIMATES(i);
        end
        if strcmp(NAMES_ALL(i),'mu1')==1
            mu1 = ZESTIMATES(i);
        end
        if strcmp(NAMES_ALL(i),'mu2')==1
            mu2 = ZESTIMATES(i);
        end
        if strcmp(NAMES_ALL(i),'mu3')==1
            mu3 = ZESTIMATES(i);
        end
        if strcmp(NAMES_ALL(i),'puh13')==1
            puh13 = ZESTIMATES(i);
        end
        if strcmp(NAMES_ALL(i),'puh23')==1
            puh23 = ZESTIMATES(i);
        end
        if strcmp(NAMES_ALL(i),'eta_b')==1
            eta_b = ZESTIMATES(i);
        end        
        if strcmp(NAMES_ALL(i),'sig_b')==1
            sig_b = ZESTIMATES(i);
        end
        if strcmp(NAMES_ALL(i),'sig_y_tilda')==1
            sig_y_tilda = ZESTIMATES(i);
        end		        
    end
end

%% Time trend in productivity, i.e., learning by doing.
if strcmp(timetrend,'logit')==1
    for i=1:length(coef)
        if strcmp(NAMES(i),'a1')==1
            a1=coef(i);
        end
        if strcmp(NAMES(i),'a2')==1
            a2=coef(i);
        end
    end
end    


if strcmp(baseline,'LBD_only')~=1 && strcmp(baseline,'earn_params_only')~=1  
   
%% Skill accumulation at outside option.
% First 5 weeks
if strcmp(first5,'first5')==1 && strcmp(runmode,'test_mode')~=1
    for i=NBASEPARAMS:length(coef)
        if strcmp(NAMES(i),'v_ojt')==1
            v_ojt=coef(i);
        end
    end
end
% Alternative time trend in outside option: Logit.
if strcmp(ootimetrend,'logit')==1 
    for i=NBASEPARAMS:length(coef)
        if strcmp(NAMES(i),'theta1')==1
            theta1=coef(i);
        end
        if strcmp(NAMES(i),'theta2')==1
            theta2=coef(i);
        end
    end
end


%% Unobserved heterogeneity in taste for the job.
if strcmp(tasteuh,'mp3')==1 || strcmp(tasteuh,'mp3_3types')==1
    for i=NBASEPARAMS:length(coef)
        if strcmp(NAMES(i),'mu1')==1
            mu1=coef(i);
        end
        if strcmp(NAMES(i),'mu2')==1
            mu2=coef(i);
        end
        if strcmp(NAMES(i),'mu3')==1
            mu3=coef(i);
        end
        if strcmp(NAMES(i),'puh13')==1
            puh13=coef(i);
            if strcmp(tasteuhprobrestrict,'yes')==1
                puh13 = LogitMH(puh13);
            end
        end
        if strcmp(NAMES(i),'puh23')==1
            puh23=coef(i);
            if strcmp(tasteuhprobrestrict,'yes')==1
                puh23 = LogitMH(puh23);
            end
        end
    end
end

%% Belief bias parameters.
if strcmp(beliefbias,'no_bias')==1 && strcmp(runmode,'test_mode')~=1
    for i=NBASEPARAMS:length(coef)
        if strcmp(NAMES(i),'sig_b')==1
            sig_b=coef(i);
        end
    end
end
if strcmp(beliefbias,'prior')==1 && strcmp(runmode,'test_mode')~=1
    for i=NBASEPARAMS:length(coef)
        if strcmp(NAMES(i),'eta_b')==1
            eta_b=coef(i);
        end
        if strcmp(NAMES(i),'sig_b')==1
            sig_b=coef(i);
        end
    end
end


%% Generalized learning (as opposed to Bayesian learning).
if strcmp(learnspeed,'general')==1 && strcmp(runmode,'test_mode')==0
    for i=NBASEPARAMS:length(coef)
        if strcmp(NAMES(i),'sig_y_tilda')==1
            sig_y_tilda=coef(i);
        end
    end
end

end
