%{
====================================================
Function name: sum_stats.m
Project: Overconfidence in Trucking
Description: Makes summary stats on turnover, miles, beliefs.

Key parts of this file:
(1) Set bandwidths for different graphs.
(2) Make different graphs:
====================================================
%}

tic

%% Set bandwidths for different graphs
bw_quithaz=6;  
bw_earnprof = 5;
bw_beliefs = 10;
bw_quithazearn = 5;

stayhaz=[]; numbatrisk=[];
sumearn=[]; numbearn=[]; 
sumbeliefs=[]; 
stayhazearn = [];

% Hazard of staying each week: stay(t)/[stay(t)+quit(t)].
for t=1:NDEC
    m_one_stayhaz = sum(stay(:,t)==1)/sum((stay(:,t)==0) + (stay(:,t)==1));
    stayhaz = [stayhaz m_one_stayhaz];
end

numbatrisk = sum((stay~=-9),1)';
stayhaz = stayhaz';
quithaz = 1-stayhaz;


%% Un-smoothed quiz hazard curve
plot(1:NDEC,quithaz)
title('Hazard of Quitting, Data Subsample')
xlabel('Week')
ylabel('Hazard of Quitting')
ylim([0 .06])


%% Smoothed quiz hazard curve
% We smooth using our own handwritten smoother.
quithaz_sm = smoothed_haz(quithaz,bw_quithaz);
plot(1:NDEC,quithaz_sm)
title('Hazard of Quitting, Data Subsample')
xlabel('Week')
ylabel('Hazard of Quitting')
ylim([0 .06])

%% Kaplan-Meier Survival Function
% "surviv(t)" is the probabiliity of survival to start of week t.
% Thus, for NDEC decisions, "surviv" will be (NDEC+1)x1.
% "surviv(NDEC+1)" is survival at the start of week (NDEC+1) or 
% equivalently at the end of week NDEC.
surviv = zeros(NDEC,1);
surviv(1)=stayhaz(1);
for k=2:NDEC
    surviv(k)=surviv(k-1)*stayhaz(k);
end
surviv = [1; surviv];

%% The average of raw miles over time. 
for t=T_NOLEARN+1:NDEC
% m_one_earn = sum(earn_raw(:,t).*(earn_raw(:,t)>0))/sum(1.*(earn_raw(:,t)>0));
m_one_earn = sum(earn_raw(:,t).*(earn_raw(:,t)>0).*(stay(:,t)~=-9))...
    /sum((stay(:,t)~=-9).*(earn_raw(:,t)>0));
sumearn = [sumearn m_one_earn];
end
sumearn_sm = smoothed_haz(sumearn,bw_earnprof);


%% The average of raw beliefs over time.
for t=T_NOLEARN+1:NDEC
% m_one_beliefs = sum(beliefs_raw(:,t).*(beliefs_raw(:,t)>0))/sum(1.*(beliefs_raw(:,t)>0));
m_one_beliefs = sum(beliefs_raw(:,t).*(beliefs_raw(:,t)>0).*(stay(:,t)~=-9))...
    /sum((stay(:,t)~=-9).*(beliefs_raw(:,t)>0));
    sumbeliefs = [sumbeliefs m_one_beliefs];
end
sumbeliefs_sm = smoothed_haz(sumbeliefs,bw_beliefs);


%% Cumulative Distriubtion of Earnings over Time
% For this, we use miles on the grid.
% Thus, it uses "earn" instead of "earn_raw".
earnings_dist = zeros(length(grid_ys),NDEC); 
cumearnings_dist= zeros(length(grid_ys),NDEC);
for t=1:NDEC
    for i=1:length(grid_ys)
        earnings_dist(i,t)=(sum(earn(:,t)==grid_ys(i)))/sum(earn(:,t)>0);
    end
    cumearnings_dist(:,t)=cumsum(earnings_dist(:,t));
end


toc
