%{
====================================================
Script name: zz_set_tasteuh_other.m
Modified: December 2018
Project: Overconfidence
Description: Alternative settings for names and
starting values for other forms of unobserved heterogeneity
in taste for the job.
====================================================
%}


% Normal unobserved heterogeneity in taste for job.
if strcmp(op.tasteuh,'normal')==1
    NAMES(end+1:end+2)={'mu_alp';'sig_alp'};
    STARTING(end+1:end+2) = [-1.5;.3];
end

% Normal unobserved heterogeneity, zero mean
if strcmp(op.tasteuh,'normal_mean0')==1
    NAMES(end+1)={'sig_alp'};
    STARTING(end+1) = [1];
end

% Two mass point UH in taste for the job.
if strcmp(op.tasteuh,'mp2')==1
    NAMES(end+1:end+3)={'mu1';'mu2';'puh12'};
    STARTING(end+1:end+3)=[0;1;.4];
end

% Two mass point Uh in taste. Only one mean different from 0.
if strcmp(op.tasteuh,'mp2_nomu2')==1
    NAMES(end+1:end+2)={'mu1';'puh12'};
    STARTING(end+1:end+2)=[0;.4];
end

% Two mass point UH in taste for job & belief bias. Belief params listed
% below.
if strcmp(op.tasteuh,'mp2_2types')==1
    NAMES(end+1:end+3)={'mu1';'mu2';'puh12'};
    STARTING(end+1:end+3)=[-2;1;.4];
end



% Three mass point UH in beliefs/taste for job
if strcmp(op.tasteuh,'mp3_3types')==1
    NAMES(end+1:end+5)={'mu1';'mu2';'mu3';'puh13';'puh23'};
    if strcmp(tasteuhprobrestrict,'yes')==0
        STARTING(end+1:end+5)=[-3;-1;2;.2;.4];
    elseif strcmp(tasteuhprobrestrict,'yes')==1
        STARTING(end+1:end+5)=[-3;0;3;log(.4/(1-.4));log(.4/(1-.4))];
    end
end

% Four mass point UH in beliefs/taste for job or in taste for job.
if strcmp(tasteuh,'mp4_4types')==1 || strcmp(tasteuh,'mp4')==1
    NAMES(end+1:end+7)={'mu1';'mu2';'mu3';'mu4';'puh14';'puh24';'puh34'};
    if strcmp(tasteuhprobrestrict,'yes')==0
        STARTING(end+1:end+7)=[-3;-2;-1;2;.2;.2;.4];
    elseif strcmp(tasteuhprobrestrict,'yes')==1
        STARTING(end+1:end+7)=[-3;-2;-1;2;log(.25/(1-.25));log(.25/(1-.25));log(.25/(1-.25))];
    end
end

% Five mass point UH in beliefs/taste for job or in taste for job.
if strcmp(tasteuh,'mp5_5types')==1 || strcmp(tasteuh,'mp5')==1
    NAMES(end+1:end+9)={'mu1';'mu2';'mu3';'mu4';'mu5';'puh15';'puh25';'puh35';'puh45'};
    if strcmp(tasteuhprobrestrict,'yes')==0
        STARTING(end+1:end+9)=[-10;-5;-3;-1;1;.2;.2;.2;.2];
    elseif strcmp(tasteuhprobrestrict,'yes')==1
        STARTING(end+1:end+9)=[-10;-5;-3;-1;1;log(.1/(1-.1));log(.2/(1-.2));log(.2/(1-.2));log(.2/(1-.2))];
    end
end

% Six mass point UH in beliefs/taste for job
if strcmp(tasteuh,'mp6_6types')==1
    NAMES(end+1:end+11)={'mu1';'mu2';'mu3';'mu4';'mu5';'mu6';'puh16';'puh26';'puh36';'puh46';'puh56'};
    if strcmp(tasteuhprobrestrict,'yes')==0
        STARTING(end+1:end+11)=[-10;-5;-3;-2;-1;1;.1;.1;.2;.2;.2];
    elseif strcmp(tasteuhprobrestrict,'yes')==1
        STARTING(end+1:end+11)=[-10;-5;-3;-2;-1;1;log(.1/(1-.1));log(.1/(1-.1));log(.2/(1-.2));log(.2/(1-.2));log(.2/(1-.2))];
    end
end