%{
====================================================
Script name: zz_std_options.m
Project: Overconfidence
Description: Specifies standard options.
====================================================
%}

% DATA NAMES
%{
MAIN DATA FOR OVERCONFIDENCE PAPER:
~ 'Panel_Truck.asc'

DATA USED WHEN CORRECTING FOR MEASUREMENT ERROR:
~ 'Panel_Truck_ME.asc'
%}
op.dataname = 'Panel_Truck.asc';

% What is 'baseline': baseline = estimating all params.
% op.baseline = 'LBD_only' means only learning by doing.
op.baseline = 'baseline';

% What variable is learning on?
op.learnover = 'miles';


%{
SPEED OF LEARNING
op.learnspeed = 'general'; % allows for a sigma_y_tilda
op.learnspeed = 'standard'; % no sigma_y_tilda
%}
op.learnspeed = 'general';

%{
(.80)^(1/52); % Annual discount factor of 0.8. STANDARD FOR PAPER.
(.9)^(1/52); % For a robustness check
%}
op.delta=(.80)^(1/52); 

%{
INVERSE PROBABILITY WEIGHTING:
op.ipw = 'no'; % No inverse probability weighting
op.ipw = 'yes'
%}
op.ipw = 'no';


% UNOBSERVED HETEROGENEITY IN TASTE FOR THE JOB.
% tasteuh: no, mp2, mp2_nomu2, normal, normal_mean0, mp3, mp4, mp5 
    % mp2_nomu2_corr, mp2_2types, mp3_3types, mp4_4types, 
    % mp5_5types, mp6_6types  
    % normal_corr, normal_corr_mean0
op.tasteuh = 'mp3';


% tasteuhprobrestrict: no, yes. Whether restrict taste uh probs
% to be between 0 and 1.
op.tasteuhprobrestrict = 'no';


%{
THRESHOLD FOR THE HIGHEST BELIEF
This is the threshold above which we trim beliefs. 
op.BELIEFTHRES=10000; % Sets maximum belief to 10k miles.
op.BELIEFTHRES=4000;  % Another option.
%}
op.BELIEFTHRES=10000;


%{
WINSORIZATION THRESHOLD FOR THE MILEAGE BELIEF DATA.
op.WINSTHRES = 10000; % Set wins thres to belief threshold of 10k miles.
4000; % Alternative for a robustness check.
%}
op.WINSTHRES = 10000;


%{
NPER = # of periods THAT WE USE FOR THE STRUCTURAL MODEL.
Also, experiment with 200 weeks later for robustness.
%}
NPER = 130;


% MILEAGE GRID
%{
(1:3:40)'; % MAIN. Increments of 300 miles from 100 to 4k miles.
(1:1:40)'; % For robustness analysis, finer grid.
(1:.75:40)'; % Even finer grid.
%}
op.grid_ys =(1:3:40)';

% Training contract: drivers have 12-month training contract.
% In separate paper on training contracts, we also analyze
% impact of 'no_contract' and '18month'. 
op.contract = '12month';


% Set a worker's weekly outside option, 'rwage'.
CPS_AnnualEarn = 32000;
WeeksPerYear = 50;
rwage = (1/100)*(CPS_AnnualEarn/WeeksPerYear); 

% The baseline counterfactual is listed as 'none'.
counterfactual = 'none';
overconf_factor = 1;

% Solvers
%{
'fminunc' = Quasi-Newton, unconstrained.
'fmincon' = Quasi-Newton, constrained.
'fminsearch' = Nelder-Mead.
'SA' = simulated annealing.
'knitro' = KNITRO.
'none' = don't estimate.
%}
op.solver = 'fminunc';

% Convergence criterion based on change in the log-likelihood that is
% considered to represent convergence. 
%{
If the log-likelihood value changes less than LLTOL from one iteration to 
the next, then the optimization routine considers convergence to have been 
achieved. The default is 1e-6, which is used when LLTOL=[];
%}
op.LLTOL = 2e-5;

% Allow a separate tolerance for "fminsearch".
op.LLTOL_FMS = 1e-5;

% Allow a separate tolerance for "simulannealbnd".
op.LLTOL_SA = 2e-5;

%{
X-TOLERANCE.
Convergence criterion based on max change in parameters that is considered
to represent convergence. This may not be "real convergence". More typical
convergence is achieved based on LLTOL.

If all the parameters change by less than PARAMTOL 
from one iteration to the next, then the code considers convergence to have 
been "achieved". The default is 1e-6, which is used when PARAMTOL=[];
PARAMTOL=[ ];
PARAMTOL = 1e-9;    
%}
op.PARAMTOL = 1e-9;

% Maximum number of iterations for the optimization routine.
%{
The code will abort after ITERMAX iterations, even if convergence has
not been achieved. The default is 400, which is used when MAXITERS=[];
~ MAXITERS=[500];  % THIS IS MAIN ONE WE USE
~ MAXITERS=[2500];
%}
op.MAXITERS = 500;

% Tolerance for numerical derivatives.
op.tol_ND = 1e-7;

% Lower bound on level of UH for base spec.
op.MU_LB_BASE = -3.75;

% Lower bound on level of UH for base spec.
op.MU_LB_LBD = -20;


